**To delete a policy store**

The following ``delete-policy-store`` example deletes the policy store that has the specified Id. ::

    aws verifiedpermissions delete-policy-store \
        --policy-store-id PSEXAMPLEabcdefg111111

This command produces no output.

For more information about policy stores, see `Amazon Verified Permissions policy stores <https://docs.aws.amazon.com/verifiedpermissions/latest/userguide/policy-stores.html>`__ in the *Amazon Verified Permissions User Guide*.